complete -c genact -s m -l modules -d 'Run only these modules' -r -f -a "{ansible	'',bootlog	'',botnet	'',bruteforce	'',cargo	'',cc	'',composer	'',cryptomining	'',docker_build	'',docker_image_rm	'',download	'',julia	'',kernel_compile	'',memdump	'',mkinitcpio	'',rkhunter	'',simcity	'',terraform	'',weblog	''}"
complete -c genact -s s -l speed-factor -d 'Global speed factor' -r
complete -c genact -s i -l instant-print-lines -d 'Instantly print this many lines' -r
complete -c genact -l exit-after-time -d 'Exit after running for this long (format example: 2h10min)' -r
complete -c genact -l exit-after-modules -d 'Exit after running this many modules' -r
complete -c genact -l print-completions -d 'Generate completion file for a shell' -r -f -a "{bash	'',elvish	'',fish	'',powershell	'',zsh	''}"
complete -c genact -s l -l list-modules -d 'List available modules'
complete -c genact -l print-manpage -d 'Generate man page'
complete -c genact -s h -l help -d 'Print help'
complete -c genact -s V -l version -d 'Print version'
